from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BsPeriodictyCls:
	"""BsPeriodicty commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bsPeriodicty", core, parent)

	def set(self, burst_set_per: enums.Nr5Gbsp, cellNull=repcap.CellNull.Default, indexNull=repcap.IndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:SSPBch<SSB(ST0)>:BSPeriodicty \n
		Snippet: driver.source.bb.nr5G.node.cell.sspbch.bsPeriodicty.set(burst_set_per = enums.Nr5Gbsp.BS10, cellNull = repcap.CellNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the burst set periodicity. \n
			:param burst_set_per: BS5| BS10| BS20| BS40| BS80| BS160| BS320| BS640
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sspbch')
		"""
		param = Conversions.enum_scalar_to_str(burst_set_per, enums.Nr5Gbsp)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		indexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:SSPBch{indexNull_cmd_val}:BSPeriodicty {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default, indexNull=repcap.IndexNull.Default) -> enums.Nr5Gbsp:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:SSPBch<SSB(ST0)>:BSPeriodicty \n
		Snippet: value: enums.Nr5Gbsp = driver.source.bb.nr5G.node.cell.sspbch.bsPeriodicty.get(cellNull = repcap.CellNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the burst set periodicity. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sspbch')
			:return: burst_set_per: BS5| BS10| BS20| BS40| BS80| BS160| BS320| BS640"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		indexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:SSPBch{indexNull_cmd_val}:BSPeriodicty?')
		return Conversions.str_to_scalar_enum(response, enums.Nr5Gbsp)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlCls:
	"""Sl commands group definition. 6 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sl", core, parent)

	@property
	def binPeriod(self):
		"""binPeriod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_binPeriod'):
			from .BinPeriod import BinPeriodCls
			self._binPeriod = BinPeriodCls(self._core, self._cmd_group)
		return self._binPeriod

	@property
	def inCoverage(self):
		"""inCoverage commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_inCoverage'):
			from .InCoverage import InCoverageCls
			self._inCoverage = InCoverageCls(self._core, self._cmd_group)
		return self._inCoverage

	@property
	def interval(self):
		"""interval commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_interval'):
			from .Interval import IntervalCls
			self._interval = IntervalCls(self._core, self._cmd_group)
		return self._interval

	@property
	def sbits(self):
		"""sbits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sbits'):
			from .Sbits import SbitsCls
			self._sbits = SbitsCls(self._core, self._cmd_group)
		return self._sbits

	@property
	def tddConf(self):
		"""tddConf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tddConf'):
			from .TddConf import TddConfCls
			self._tddConf = TddConfCls(self._core, self._cmd_group)
		return self._tddConf

	@property
	def toffs(self):
		"""toffs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_toffs'):
			from .Toffs import ToffsCls
			self._toffs = ToffsCls(self._core, self._cmd_group)
		return self._toffs

	def clone(self) -> 'SlCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SlCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BitsCls:
	"""Bits commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bits", core, parent)

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default, codeword=repcap.Codeword.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:[CELL<CCIDX>]:[SUBF<ST0>]:ALLoc<CH0>:[CW<CWID>]:PUACh:ULSCh:BITS \n
		Snippet: value: int = driver.source.bb.oneweb.uplink.cell.subf.alloc.cw.puach.ulsch.bits.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default, codeword = repcap.Codeword.Default) \n
		Queries the number of physical bits used for UL-SCH transmission. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param codeword: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cw')
			:return: phys_bit_count: integer Range: 0 to max"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		codeword_cmd_val = self._cmd_group.get_repcap_cmd_value(codeword, repcap.Codeword)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:UL:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CW{codeword_cmd_val}:PUACh:ULSCh:BITS?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class L2BandCls:
	"""L2Band commands group definition. 59 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("l2Band", core, parent)

	@property
	def c1C(self):
		"""c1C commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_c1C'):
			from .C1C import C1CCls
			self._c1C = C1CCls(self._core, self._cmd_group)
		return self._c1C

	@property
	def c2C(self):
		"""c2C commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_c2C'):
			from .C2C import C2CCls
			self._c2C = C2CCls(self._core, self._cmd_group)
		return self._c2C

	@property
	def ca(self):
		"""ca commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ca'):
			from .Ca import CaCls
			self._ca = CaCls(self._core, self._cmd_group)
		return self._ca

	@property
	def l2C(self):
		"""l2C commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_l2C'):
			from .L2C import L2CCls
			self._l2C = L2CCls(self._core, self._cmd_group)
		return self._l2C

	@property
	def m(self):
		"""m commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_m'):
			from .M import MCls
			self._m = MCls(self._core, self._cmd_group)
		return self._m

	@property
	def p(self):
		"""p commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_p'):
			from .P import PCls
			self._p = PCls(self._core, self._cmd_group)
		return self._p

	@property
	def py(self):
		"""py commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_py'):
			from .Py import PyCls
			self._py = PyCls(self._core, self._cmd_group)
		return self._py

	def clone(self) -> 'L2BandCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = L2BandCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TfConfigCls:
	"""TfConfig commands group definition. 40 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tfConfig", core, parent)

	@property
	def cinfo(self):
		"""cinfo commands group. 20 Sub-classes, 0 commands."""
		if not hasattr(self, '_cinfo'):
			from .Cinfo import CinfoCls
			self._cinfo = CinfoCls(self._core, self._cmd_group)
		return self._cinfo

	@property
	def eof(self):
		"""eof commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_eof'):
			from .Eof import EofCls
			self._eof = EofCls(self._core, self._cmd_group)
		return self._eof

	@property
	def nuInfo(self):
		"""nuInfo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nuInfo'):
			from .NuInfo import NuInfoCls
			self._nuInfo = NuInfoCls(self._core, self._cmd_group)
		return self._nuInfo

	@property
	def padLength(self):
		"""padLength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_padLength'):
			from .PadLength import PadLengthCls
			self._padLength = PadLengthCls(self._core, self._cmd_group)
		return self._padLength

	@property
	def tpTime(self):
		"""tpTime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpTime'):
			from .TpTime import TpTimeCls
			self._tpTime = TpTimeCls(self._core, self._cmd_group)
		return self._tpTime

	@property
	def uinfo(self):
		"""uinfo commands group. 16 Sub-classes, 0 commands."""
		if not hasattr(self, '_uinfo'):
			from .Uinfo import UinfoCls
			self._uinfo = UinfoCls(self._core, self._cmd_group)
		return self._uinfo

	def clone(self) -> 'TfConfigCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TfConfigCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrcCls:
	"""Frc commands group definition. 7 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frc", core, parent)

	@property
	def alrb(self):
		"""alrb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_alrb'):
			from .Alrb import AlrbCls
			self._alrb = AlrbCls(self._core, self._cmd_group)
		return self._alrb

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def n2Dmrs(self):
		"""n2Dmrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_n2Dmrs'):
			from .N2Dmrs import N2DmrsCls
			self._n2Dmrs = N2DmrsCls(self._core, self._cmd_group)
		return self._n2Dmrs

	@property
	def paSize(self):
		"""paSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_paSize'):
			from .PaSize import PaSizeCls
			self._paSize = PaSizeCls(self._core, self._cmd_group)
		return self._paSize

	@property
	def tnoBits(self):
		"""tnoBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tnoBits'):
			from .TnoBits import TnoBitsCls
			self._tnoBits = TnoBitsCls(self._core, self._cmd_group)
		return self._tnoBits

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def vrbOffset(self):
		"""vrbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vrbOffset'):
			from .VrbOffset import VrbOffsetCls
			self._vrbOffset = VrbOffsetCls(self._core, self._cmd_group)
		return self._vrbOffset

	def clone(self) -> 'FrcCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrcCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PdschCls:
	"""Pdsch commands group definition. 38 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdsch", core, parent)

	@property
	def bmaid(self):
		"""bmaid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bmaid'):
			from .Bmaid import BmaidCls
			self._bmaid = BmaidCls(self._core, self._cmd_group)
		return self._bmaid

	@property
	def dmr(self):
		"""dmr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dmr'):
			from .Dmr import DmrCls
			self._dmr = DmrCls(self._core, self._cmd_group)
		return self._dmr

	@property
	def dmrs(self):
		"""dmrs commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmrs'):
			from .Dmrs import DmrsCls
			self._dmrs = DmrsCls(self._core, self._cmd_group)
		return self._dmrs

	@property
	def ncw(self):
		"""ncw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ncw'):
			from .Ncw import NcwCls
			self._ncw = NcwCls(self._core, self._cmd_group)
		return self._ncw

	@property
	def patgrp(self):
		"""patgrp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_patgrp'):
			from .Patgrp import PatgrpCls
			self._patgrp = PatgrpCls(self._core, self._cmd_group)
		return self._patgrp

	@property
	def precg(self):
		"""precg commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_precg'):
			from .Precg import PrecgCls
			self._precg = PrecgCls(self._core, self._cmd_group)
		return self._precg

	@property
	def ptrs(self):
		"""ptrs commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_ptrs'):
			from .Ptrs import PtrsCls
			self._ptrs = PtrsCls(self._core, self._cmd_group)
		return self._ptrs

	@property
	def resAlloc(self):
		"""resAlloc commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_resAlloc'):
			from .ResAlloc import ResAllocCls
			self._resAlloc = ResAllocCls(self._core, self._cmd_group)
		return self._resAlloc

	@property
	def sbcZero(self):
		"""sbcZero commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sbcZero'):
			from .SbcZero import SbcZeroCls
			self._sbcZero = SbcZeroCls(self._core, self._cmd_group)
		return self._sbcZero

	@property
	def txScheme(self):
		"""txScheme commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_txScheme'):
			from .TxScheme import TxSchemeCls
			self._txScheme = TxSchemeCls(self._core, self._cmd_group)
		return self._txScheme

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def clone(self) -> 'PdschCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PdschCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PuschCls:
	"""Pusch commands group definition. 81 total commands, 33 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pusch", core, parent)

	@property
	def a02List(self):
		"""a02List commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_a02List'):
			from .A02List import A02ListCls
			self._a02List = A02ListCls(self._core, self._cmd_group)
		return self._a02List

	@property
	def accList(self):
		"""accList commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_accList'):
			from .AccList import AccListCls
			self._accList = AccListCls(self._core, self._cmd_group)
		return self._accList

	@property
	def apPresent(self):
		"""apPresent commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apPresent'):
			from .ApPresent import ApPresentCls
			self._apPresent = ApPresentCls(self._core, self._cmd_group)
		return self._apPresent

	@property
	def bharq(self):
		"""bharq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bharq'):
			from .Bharq import BharqCls
			self._bharq = BharqCls(self._core, self._cmd_group)
		return self._bharq

	@property
	def brv(self):
		"""brv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_brv'):
			from .Brv import BrvCls
			self._brv = BrvCls(self._core, self._cmd_group)
		return self._brv

	@property
	def cbSubset(self):
		"""cbSubset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbSubset'):
			from .CbSubset import CbSubsetCls
			self._cbSubset = CbSubsetCls(self._core, self._cmd_group)
		return self._cbSubset

	@property
	def dmta(self):
		"""dmta commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmta'):
			from .Dmta import DmtaCls
			self._dmta = DmtaCls(self._core, self._cmd_group)
		return self._dmta

	@property
	def dmtb(self):
		"""dmtb commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmtb'):
			from .Dmtb import DmtbCls
			self._dmtb = DmtbCls(self._core, self._cmd_group)
		return self._dmtb

	@property
	def dsid(self):
		"""dsid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dsid'):
			from .Dsid import DsidCls
			self._dsid = DsidCls(self._core, self._cmd_group)
		return self._dsid

	@property
	def dsInit(self):
		"""dsInit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dsInit'):
			from .DsInit import DsInitCls
			self._dsInit = DsInitCls(self._core, self._cmd_group)
		return self._dsInit

	@property
	def fhOffsets(self):
		"""fhOffsets commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_fhOffsets'):
			from .FhOffsets import FhOffsetsCls
			self._fhOffsets = FhOffsetsCls(self._core, self._cmd_group)
		return self._fhOffsets

	@property
	def fhop(self):
		"""fhop commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fhop'):
			from .Fhop import FhopCls
			self._fhop = FhopCls(self._core, self._cmd_group)
		return self._fhop

	@property
	def fptr(self):
		"""fptr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fptr'):
			from .Fptr import FptrCls
			self._fptr = FptrCls(self._core, self._cmd_group)
		return self._fptr

	@property
	def hp5Bits(self):
		"""hp5Bits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hp5Bits'):
			from .Hp5Bits import Hp5BitsCls
			self._hp5Bits = Hp5BitsCls(self._core, self._cmd_group)
		return self._hp5Bits

	@property
	def isin(self):
		"""isin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_isin'):
			from .Isin import IsinCls
			self._isin = IsinCls(self._core, self._cmd_group)
		return self._isin

	@property
	def mcbGroups(self):
		"""mcbGroups commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcbGroups'):
			from .McbGroups import McbGroupsCls
			self._mcbGroups = McbGroupsCls(self._core, self._cmd_group)
		return self._mcbGroups

	@property
	def mcsTable(self):
		"""mcsTable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcsTable'):
			from .McsTable import McsTableCls
			self._mcsTable = McsTableCls(self._core, self._cmd_group)
		return self._mcsTable

	@property
	def mrank(self):
		"""mrank commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mrank'):
			from .Mrank import MrankCls
			self._mrank = MrankCls(self._core, self._cmd_group)
		return self._mrank

	@property
	def mttPrecoding(self):
		"""mttPrecoding commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mttPrecoding'):
			from .MttPrecoding import MttPrecodingCls
			self._mttPrecoding = MttPrecodingCls(self._core, self._cmd_group)
		return self._mttPrecoding

	@property
	def oi01(self):
		"""oi01 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_oi01'):
			from .Oi01 import Oi01Cls
			self._oi01 = Oi01Cls(self._core, self._cmd_group)
		return self._oi01

	@property
	def olpc(self):
		"""olpc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_olpc'):
			from .Olpc import OlpcCls
			self._olpc = OlpcCls(self._core, self._cmd_group)
		return self._olpc

	@property
	def pi01(self):
		"""pi01 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pi01'):
			from .Pi01 import Pi01Cls
			self._pi01 = Pi01Cls(self._core, self._cmd_group)
		return self._pi01

	@property
	def pi02(self):
		"""pi02 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pi02'):
			from .Pi02 import Pi02Cls
			self._pi02 = Pi02Cls(self._core, self._cmd_group)
		return self._pi02

	@property
	def ppsl(self):
		"""ppsl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ppsl'):
			from .Ppsl import PpslCls
			self._ppsl = PpslCls(self._core, self._cmd_group)
		return self._ppsl

	@property
	def rbgSize(self):
		"""rbgSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbgSize'):
			from .RbgSize import RbgSizeCls
			self._rbgSize = RbgSizeCls(self._core, self._cmd_group)
		return self._rbgSize

	@property
	def resAlloc(self):
		"""resAlloc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_resAlloc'):
			from .ResAlloc import ResAllocCls
			self._resAlloc = ResAllocCls(self._core, self._cmd_group)
		return self._resAlloc

	@property
	def scrambling(self):
		"""scrambling commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_scrambling'):
			from .Scrambling import ScramblingCls
			self._scrambling = ScramblingCls(self._core, self._cmd_group)
		return self._scrambling

	@property
	def t1Gran(self):
		"""t1Gran commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_t1Gran'):
			from .T1Gran import T1GranCls
			self._t1Gran = T1GranCls(self._core, self._cmd_group)
		return self._t1Gran

	@property
	def tpState(self):
		"""tpState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpState'):
			from .TpState import TpStateCls
			self._tpState = TpStateCls(self._core, self._cmd_group)
		return self._tpState

	@property
	def txConfig(self):
		"""txConfig commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_txConfig'):
			from .TxConfig import TxConfigCls
			self._txConfig = TxConfigCls(self._core, self._cmd_group)
		return self._txConfig

	@property
	def u2Tpc(self):
		"""u2Tpc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_u2Tpc'):
			from .U2Tpc import U2TpcCls
			self._u2Tpc = U2TpcCls(self._core, self._cmd_group)
		return self._u2Tpc

	@property
	def uitl(self):
		"""uitl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uitl'):
			from .Uitl import UitlCls
			self._uitl = UitlCls(self._core, self._cmd_group)
		return self._uitl

	@property
	def xoverhead(self):
		"""xoverhead commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xoverhead'):
			from .Xoverhead import XoverheadCls
			self._xoverhead = XoverheadCls(self._core, self._cmd_group)
		return self._xoverhead

	def clone(self) -> 'PuschCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PuschCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DisconnectCls:
	"""Disconnect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("disconnect", core, parent)

	def set(self, path=repcap.Path.Default) -> None:
		"""SCPI: SCONfiguration:EXTernal:RF<CH>:REMote:DISConnect \n
		Snippet: driver.sconfiguration.external.rf.remote.disconnect.set(path = repcap.Path.Default) \n
		Disconnects the selected remote connection. To disconnect all remote connections at once, use the command method RsSmw.
		Sconfiguration.External.Remote.Disconnect.All.set. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
		"""
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SCONfiguration:EXTernal:RF{path_cmd_val}:REMote:DISConnect')

	def set_with_opc(self, path=repcap.Path.Default, opc_timeout_ms: int = -1) -> None:
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		"""SCPI: SCONfiguration:EXTernal:RF<CH>:REMote:DISConnect \n
		Snippet: driver.sconfiguration.external.rf.remote.disconnect.set_with_opc(path = repcap.Path.Default) \n
		Disconnects the selected remote connection. To disconnect all remote connections at once, use the command method RsSmw.
		Sconfiguration.External.Remote.Disconnect.All.set. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCONfiguration:EXTernal:RF{path_cmd_val}:REMote:DISConnect', opc_timeout_ms)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DmrCls:
	"""Dmr commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dmr", core, parent)

	@property
	def nidDel(self):
		"""nidDel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nidDel'):
			from .NidDel import NidDelCls
			self._nidDel = NidDelCls(self._core, self._cmd_group)
		return self._nidDel

	def set(self, dmrs_ni_drs: int, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:DMR \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.dmr.set(dmrs_ni_drs = 1, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		No command help available \n
			:param dmrs_ni_drs: No help available
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
		"""
		param = Conversions.decimal_value_to_str(dmrs_ni_drs)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:DMR {param}')

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:DMR \n
		Snippet: value: int = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.dmr.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		No command help available \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: dmrs_ni_drs: No help available"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:DMR?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'DmrCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DmrCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EmcsCls:
	"""Emcs commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("emcs", core, parent)

	def set(self, eht_sig_mcs: enums.WlannFbMcs, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:EMCS \n
		Snippet: driver.source.bb.wlnn.fblock.emcs.set(eht_sig_mcs = enums.WlannFbMcs.MCS0, frameBlock = repcap.FrameBlock.Default) \n
		Sets the modulation coding scheme for modulation of the EHT-SIG bits. \n
			:param eht_sig_mcs: MCS0| MCS1| MCS3| MCS15
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.enum_scalar_to_str(eht_sig_mcs, enums.WlannFbMcs)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:EMCS {param}')

	# noinspection PyTypeChecker
	def get(self, frameBlock=repcap.FrameBlock.Default) -> enums.WlannFbMcs:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:EMCS \n
		Snippet: value: enums.WlannFbMcs = driver.source.bb.wlnn.fblock.emcs.get(frameBlock = repcap.FrameBlock.Default) \n
		Sets the modulation coding scheme for modulation of the EHT-SIG bits. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: eht_sig_mcs: MCS0| MCS1| MCS3| MCS15"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:EMCS?')
		return Conversions.str_to_scalar_enum(response, enums.WlannFbMcs)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TapCls:
	"""Tap commands group definition. 377 total commands, 5 Subgroups, 1 group commands
	Repeated Capability: MimoTap, default value after init: MimoTap.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tap", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_mimoTap_get', 'repcap_mimoTap_set', repcap.MimoTap.Nr1)

	def repcap_mimoTap_set(self, mimoTap: repcap.MimoTap) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to MimoTap.Default
		Default value after init: MimoTap.Nr1"""
		self._cmd_group.set_repcap_enum_value(mimoTap)

	def repcap_mimoTap_get(self) -> repcap.MimoTap:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def antenna(self):
		"""antenna commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import AntennaCls
			self._antenna = AntennaCls(self._core, self._cmd_group)
		return self._antenna

	@property
	def gvector(self):
		"""gvector commands group. 66 Sub-classes, 1 commands."""
		if not hasattr(self, '_gvector'):
			from .Gvector import GvectorCls
			self._gvector = GvectorCls(self._core, self._cmd_group)
		return self._gvector

	@property
	def kronecker(self):
		"""kronecker commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_kronecker'):
			from .Kronecker import KroneckerCls
			self._kronecker = KroneckerCls(self._core, self._cmd_group)
		return self._kronecker

	@property
	def matrix(self):
		"""matrix commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_matrix'):
			from .Matrix import MatrixCls
			self._matrix = MatrixCls(self._core, self._cmd_group)
		return self._matrix

	@property
	def tgn(self):
		"""tgn commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tgn'):
			from .Tgn import TgnCls
			self._tgn = TgnCls(self._core, self._cmd_group)
		return self._tgn

	# noinspection PyTypeChecker
	def get_value(self) -> enums.FadMimoTap:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:TAP \n
		Snippet: value: enums.FadMimoTap = driver.source.fsimulator.mimo.tap.get_value() \n
		Sets the current tap. \n
			:return: tap: TAP1| TAP2| TAP3| TAP4| TAP5| TAP6| TAP7| TAP8| TAP9| TAP10| TAP11| TAP12| TAP13| TAP14| TAP15| TAP16| TAP17| TAP18| TAP19| TAP20
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:MIMO:TAP?')
		return Conversions.str_to_scalar_enum(response, enums.FadMimoTap)

	def set_value(self, tap: enums.FadMimoTap) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:TAP \n
		Snippet: driver.source.fsimulator.mimo.tap.set_value(tap = enums.FadMimoTap.TAP1) \n
		Sets the current tap. \n
			:param tap: TAP1| TAP2| TAP3| TAP4| TAP5| TAP6| TAP7| TAP8| TAP9| TAP10| TAP11| TAP12| TAP13| TAP14| TAP15| TAP16| TAP17| TAP18| TAP19| TAP20
		"""
		param = Conversions.enum_scalar_to_str(tap, enums.FadMimoTap)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:TAP {param}')

	def clone(self) -> 'TapCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TapCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class L5SCls:
	"""L5S commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("l5S", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SYSTem:QZSS:SIGNal:L5Band:L5S:[STATe] \n
		Snippet: value: bool = driver.source.bb.gnss.system.qzss.signal.l5Band.l5S.get_state() \n
		Enables the corresponding signal from the GNSS system in the corresponding RF band. \n
			:return: signal_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SYSTem:QZSS:SIGNal:L5Band:L5S:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, signal_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SYSTem:QZSS:SIGNal:L5Band:L5S:[STATe] \n
		Snippet: driver.source.bb.gnss.system.qzss.signal.l5Band.l5S.set_state(signal_state = False) \n
		Enables the corresponding signal from the GNSS system in the corresponding RF band. \n
			:param signal_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(signal_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SYSTem:QZSS:SIGNal:L5Band:L5S:STATe {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DisconnectCls:
	"""Disconnect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("disconnect", core, parent)

	def set(self, index=repcap.Index.Default) -> None:
		"""SCPI: SCONfiguration:EXTernal:HSDigital<CH>:REMote:DISConnect \n
		Snippet: driver.sconfiguration.external.hsDigital.remote.disconnect.set(index = repcap.Index.Default) \n
		No command help available \n
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'HsDigital')
		"""
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		self._core.io.write(f'SCONfiguration:EXTernal:HSDigital{index_cmd_val}:REMote:DISConnect')

	def set_with_opc(self, index=repcap.Index.Default, opc_timeout_ms: int = -1) -> None:
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		"""SCPI: SCONfiguration:EXTernal:HSDigital<CH>:REMote:DISConnect \n
		Snippet: driver.sconfiguration.external.hsDigital.remote.disconnect.set_with_opc(index = repcap.Index.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'HsDigital')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCONfiguration:EXTernal:HSDigital{index_cmd_val}:REMote:DISConnect', opc_timeout_ms)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class B1CCls:
	"""B1C commands group definition. 10 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("b1C", core, parent)

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def pilot(self):
		"""pilot commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pilot'):
			from .Pilot import PilotCls
			self._pilot = PilotCls(self._core, self._cmd_group)
		return self._pilot

	@property
	def power(self):
		"""power commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def clone(self) -> 'B1CCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = B1CCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConflictsCls:
	"""Conflicts commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("conflicts", core, parent)

	def get(self, subframeNull=repcap.SubframeNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:CONFlicts \n
		Snippet: value: int = driver.source.bb.eutra.downlink.subf.encc.pdcch.extc.conflicts.get(subframeNull = repcap.SubframeNull.Default) \n
		Queries the number of conflicts between the DCI formats. To query whether there is a conflict in one particular PDCCH
		item, use the command [:SOURce<hw>]:BB:EUTRa:DL[:SUBF<st0>]:ENCC:PDCCh:EXTC:ITEM<ch0>:CONFlict?. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:return: no_of_conf: integer Range: 0 to 20"""
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:CONFlicts?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WlnnCls:
	"""Wlnn commands group definition. 323 total commands, 9 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("wlnn", core, parent)

	@property
	def antenna(self):
		"""antenna commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import AntennaCls
			self._antenna = AntennaCls(self._core, self._cmd_group)
		return self._antenna

	@property
	def clipping(self):
		"""clipping commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_clipping'):
			from .Clipping import ClippingCls
			self._clipping = ClippingCls(self._core, self._cmd_group)
		return self._clipping

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def fblock(self):
		"""fblock commands group. 68 Sub-classes, 2 commands."""
		if not hasattr(self, '_fblock'):
			from .Fblock import FblockCls
			self._fblock = FblockCls(self._core, self._cmd_group)
		return self._fblock

	@property
	def filterPy(self):
		"""filterPy commands group. 4 Sub-classes, 2 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def setting(self):
		"""setting commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import SettingCls
			self._setting = SettingCls(self._core, self._cmd_group)
		return self._setting

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def trigger(self):
		"""trigger commands group. 6 Sub-classes, 5 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import WaveformCls
			self._waveform = WaveformCls(self._core, self._cmd_group)
		return self._waveform

	# noinspection PyTypeChecker
	def get_bandwidth(self) -> enums.WlannTxBw:
		"""SCPI: [SOURce<HW>]:BB:WLNN:BWidth \n
		Snippet: value: enums.WlannTxBw = driver.source.bb.wlnn.get_bandwidth() \n
		The command selects the transmission bandwidth. Whenever the bandwidth changes from a higher to a lower one, the frame
		blocks are validated because some of them could be invalid in the lower bandwidth (invalid TX Mode) . \n
			:return: bwidth: BW20| BW40| BW80| BW160| BW320 Unit: MHz
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:BWidth?')
		return Conversions.str_to_scalar_enum(response, enums.WlannTxBw)

	def set_bandwidth(self, bwidth: enums.WlannTxBw) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:BWidth \n
		Snippet: driver.source.bb.wlnn.set_bandwidth(bwidth = enums.WlannTxBw.BW160) \n
		The command selects the transmission bandwidth. Whenever the bandwidth changes from a higher to a lower one, the frame
		blocks are validated because some of them could be invalid in the lower bandwidth (invalid TX Mode) . \n
			:param bwidth: BW20| BW40| BW80| BW160| BW320 Unit: MHz
		"""
		param = Conversions.enum_scalar_to_str(bwidth, enums.WlannTxBw)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:BWidth {param}')

	def set_cf_block(self, cf_block: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:CFBLock \n
		Snippet: driver.source.bb.wlnn.set_cf_block(cf_block = 1) \n
		Copies the selected frame block. \n
			:param cf_block: integer Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(cf_block)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:CFBLock {param}')

	def set_df_block(self, df_block: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:DFBLock \n
		Snippet: driver.source.bb.wlnn.set_df_block(df_block = 1) \n
		Deletes the selected frame block. \n
			:param df_block: integer Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(df_block)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:DFBLock {param}')

	def set_if_block(self, if_block: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:IFBLock \n
		Snippet: driver.source.bb.wlnn.set_if_block(if_block = 1) \n
		The command adds a default frame block before the selected frame block. \n
			:param if_block: No help available
		"""
		param = Conversions.decimal_value_to_str(if_block)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:IFBLock {param}')

	def set_pf_block(self, pf_block: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:PFBLock \n
		Snippet: driver.source.bb.wlnn.set_pf_block(pf_block = 1) \n
		Pastes the selected frame block. \n
			:param pf_block: integer Range: 1 to 99
		"""
		param = Conversions.decimal_value_to_str(pf_block)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:PFBLock {param}')

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:PRESet \n
		Snippet: driver.source.bb.wlnn.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:WLNN:STATe. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:PRESet \n
		Snippet: driver.source.bb.wlnn.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:WLNN:STATe. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:WLNN:PRESet', opc_timeout_ms)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLNN:STATe \n
		Snippet: value: bool = driver.source.bb.wlnn.get_state() \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:STATe \n
		Snippet: driver.source.bb.wlnn.set_state(state = False) \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:STATe {param}')

	def get_version(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLNN:VERSion \n
		Snippet: value: str = driver.source.bb.wlnn.get_version() \n
		Queries the version of the IEEE 802.11 WLAN standard underlying the definitions. \n
			:return: version: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:VERSion?')
		return trim_str_response(response)

	def clone(self) -> 'WlnnCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = WlnnCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UwCls:
	"""Uw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uw", core, parent)

	def set(self, uw: List[str], bitcount: int, sfCfgIxNull=repcap.SfCfgIxNull.Default, frCfgIxNull=repcap.FrCfgIxNull.Default, indexNull=repcap.IndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBR:SFConfig<CH0>:FRConfig<ST0>:SEC<DI0>:UW \n
		Snippet: driver.source.bb.dvb.dvbr.sfConfig.frConfig.sec.uw.set(uw = ['rawAbc1', 'rawAbc2', 'rawAbc3'], bitcount = 1, sfCfgIxNull = repcap.SfCfgIxNull.Default, frCfgIxNull = repcap.FrCfgIxNull.Default, indexNull = repcap.IndexNull.Default) \n
		Queries the content of the unique word (UW) . \n
			:param uw: numeric
			:param bitcount: integer Range: 1 to 512
			:param sfCfgIxNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'SfConfig')
			:param frCfgIxNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'FrConfig')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sec')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('uw', uw, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		sfCfgIxNull_cmd_val = self._cmd_group.get_repcap_cmd_value(sfCfgIxNull, repcap.SfCfgIxNull)
		frCfgIxNull_cmd_val = self._cmd_group.get_repcap_cmd_value(frCfgIxNull, repcap.FrCfgIxNull)
		indexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBR:SFConfig{sfCfgIxNull_cmd_val}:FRConfig{frCfgIxNull_cmd_val}:SEC{indexNull_cmd_val}:UW {param}'.rstrip())

	# noinspection PyTypeChecker
	class UwStruct(StructBase):
		"""Response structure. Fields: \n
			- Uw: List[str]: numeric
			- Bitcount: int: integer Range: 1 to 512"""
		__meta_args_list = [
			ArgStruct('Uw', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Uw: List[str] = None
			self.Bitcount: int = None

	def get(self, sfCfgIxNull=repcap.SfCfgIxNull.Default, frCfgIxNull=repcap.FrCfgIxNull.Default, indexNull=repcap.IndexNull.Default) -> UwStruct:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBR:SFConfig<CH0>:FRConfig<ST0>:SEC<DI0>:UW \n
		Snippet: value: UwStruct = driver.source.bb.dvb.dvbr.sfConfig.frConfig.sec.uw.get(sfCfgIxNull = repcap.SfCfgIxNull.Default, frCfgIxNull = repcap.FrCfgIxNull.Default, indexNull = repcap.IndexNull.Default) \n
		Queries the content of the unique word (UW) . \n
			:param sfCfgIxNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'SfConfig')
			:param frCfgIxNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'FrConfig')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sec')
			:return: structure: for return value, see the help for UwStruct structure arguments."""
		sfCfgIxNull_cmd_val = self._cmd_group.get_repcap_cmd_value(sfCfgIxNull, repcap.SfCfgIxNull)
		frCfgIxNull_cmd_val = self._cmd_group.get_repcap_cmd_value(frCfgIxNull, repcap.FrCfgIxNull)
		indexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:DVB:DVBR:SFConfig{sfCfgIxNull_cmd_val}:FRConfig{frCfgIxNull_cmd_val}:SEC{indexNull_cmd_val}:UW?', self.__class__.UwStruct())



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, data: enums.DataSourceA, subframeNull=repcap.SubframeNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:[SUBF<ST0>]:ENCC:PDCCh:DATA \n
		Snippet: driver.source.bb.oneweb.downlink.subf.encc.pdcch.data.set(data = enums.DataSourceA.DLISt, subframeNull = repcap.SubframeNull.Default) \n
		No command help available \n
			:param data: No help available
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
		"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceA)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default) -> enums.DataSourceA:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:[SUBF<ST0>]:ENCC:PDCCh:DATA \n
		Snippet: value: enums.DataSourceA = driver.source.bb.oneweb.downlink.subf.encc.pdcch.data.get(subframeNull = repcap.SubframeNull.Default) \n
		No command help available \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:return: data: No help available"""
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceA)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 10 total commands, 4 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	@property
	def attenuator(self):
		"""attenuator commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_attenuator'):
			from .Attenuator import AttenuatorCls
			self._attenuator = AttenuatorCls(self._core, self._cmd_group)
		return self._attenuator

	@property
	def haccuracy(self):
		"""haccuracy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_haccuracy'):
			from .Haccuracy import HaccuracyCls
			self._haccuracy = HaccuracyCls(self._core, self._cmd_group)
		return self._haccuracy

	@property
	def opu(self):
		"""opu commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_opu'):
			from .Opu import OpuCls
			self._opu = OpuCls(self._core, self._cmd_group)
		return self._opu

	@property
	def measure(self):
		"""measure commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_measure'):
			from .Measure import MeasureCls
			self._measure = MeasureCls(self._core, self._cmd_group)
		return self._measure

	# noinspection PyTypeChecker
	def get_bandwidth(self) -> enums.CalPowBandwidth:
		"""SCPI: CALibration<HW>:LEVel:BWIDth \n
		Snippet: value: enums.CalPowBandwidth = driver.calibration.level.get_bandwidth() \n
		No command help available \n
			:return: bandwidth: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:BWIDth?')
		return Conversions.str_to_scalar_enum(response, enums.CalPowBandwidth)

	def set_bandwidth(self, bandwidth: enums.CalPowBandwidth) -> None:
		"""SCPI: CALibration<HW>:LEVel:BWIDth \n
		Snippet: driver.calibration.level.set_bandwidth(bandwidth = enums.CalPowBandwidth.AUTO) \n
		No command help available \n
			:param bandwidth: No help available
		"""
		param = Conversions.enum_scalar_to_str(bandwidth, enums.CalPowBandwidth)
		self._core.io.write(f'CALibration<HwInstance>:LEVel:BWIDth {param}')

	# noinspection PyTypeChecker
	def get_det_att(self) -> enums.DetAtt:
		"""SCPI: CALibration<HW>:LEVel:DETatt \n
		Snippet: value: enums.DetAtt = driver.calibration.level.get_det_att() \n
		No command help available \n
			:return: det_att: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:DETatt?')
		return Conversions.str_to_scalar_enum(response, enums.DetAtt)

	def set_det_att(self, det_att: enums.DetAtt) -> None:
		"""SCPI: CALibration<HW>:LEVel:DETatt \n
		Snippet: driver.calibration.level.set_det_att(det_att = enums.DetAtt.HIGH) \n
		No command help available \n
			:param det_att: No help available
		"""
		param = Conversions.enum_scalar_to_str(det_att, enums.DetAtt)
		self._core.io.write(f'CALibration<HwInstance>:LEVel:DETatt {param}')

	def get_local(self) -> bool:
		"""SCPI: CALibration<HW>:LEVel:LOCal \n
		Snippet: value: bool = driver.calibration.level.get_local() \n
		No command help available \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:LOCal?')
		return Conversions.str_to_bool(response)

	# noinspection PyTypeChecker
	def get_state(self) -> enums.StateExtended:
		"""SCPI: CALibration<HW>:LEVel:STATe \n
		Snippet: value: enums.StateExtended = driver.calibration.level.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.StateExtended)

	def set_state(self, state: enums.StateExtended) -> None:
		"""SCPI: CALibration<HW>:LEVel:STATe \n
		Snippet: driver.calibration.level.set_state(state = enums.StateExtended._0) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.enum_scalar_to_str(state, enums.StateExtended)
		self._core.io.write(f'CALibration<HwInstance>:LEVel:STATe {param}')

	def clone(self) -> 'LevelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LevelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SfOffsetCls:
	"""SfOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sfOffset", core, parent)

	def set(self, sub_frame_offset: int, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:TMPH:SFOFfset \n
		Snippet: driver.source.bb.nr5G.node.cell.tmph.sfOffset.set(sub_frame_offset = 1, cellNull = repcap.CellNull.Default) \n
		Defines a cell specific cyclic subframe shift in terms of subframes. \n
			:param sub_frame_offset: integer Range: 0 to 10
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.decimal_value_to_str(sub_frame_offset)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:TMPH:SFOFfset {param}')

	def get(self, cellNull=repcap.CellNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:TMPH:SFOFfset \n
		Snippet: value: int = driver.source.bb.nr5G.node.cell.tmph.sfOffset.get(cellNull = repcap.CellNull.Default) \n
		Defines a cell specific cyclic subframe shift in terms of subframes. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: sub_frame_offset: No help available"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:TMPH:SFOFfset?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VobsCls:
	"""Vobs commands group definition. 7 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("vobs", core, parent)

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def morientation(self):
		"""morientation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_morientation'):
			from .Morientation import MorientationCls
			self._morientation = MorientationCls(self._core, self._cmd_group)
		return self._morientation

	@property
	def pmodel(self):
		"""pmodel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmodel'):
			from .Pmodel import PmodelCls
			self._pmodel = PmodelCls(self._core, self._cmd_group)
		return self._pmodel

	@property
	def predefined(self):
		"""predefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_predefined'):
			from .Predefined import PredefinedCls
			self._predefined = PredefinedCls(self._core, self._cmd_group)
		return self._predefined

	@property
	def roffset(self):
		"""roffset commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_roffset'):
			from .Roffset import RoffsetCls
			self._roffset = RoffsetCls(self._core, self._cmd_group)
		return self._roffset

	def clone(self) -> 'VobsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = VobsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DlengthCls:
	"""Dlength commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dlength", core, parent)

	def set(self, dwell_length: int, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:SFBHconfig:DT<CH0>:DLENgth \n
		Snippet: driver.source.bb.dvb.dvbs.sfbhConfig.dt.dlength.set(dwell_length = 1, channelNull = repcap.ChannelNull.Default) \n
		Sets the dwell length. \n
			:param dwell_length: integer Range: 0 to 2047974660
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Dt')
		"""
		param = Conversions.decimal_value_to_str(dwell_length)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBS:SFBHconfig:DT{channelNull_cmd_val}:DLENgth {param}')

	def get(self, channelNull=repcap.ChannelNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:SFBHconfig:DT<CH0>:DLENgth \n
		Snippet: value: int = driver.source.bb.dvb.dvbs.sfbhConfig.dt.dlength.get(channelNull = repcap.ChannelNull.Default) \n
		Sets the dwell length. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Dt')
			:return: dwell_length: integer Range: 0 to 2047974660"""
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:DVB:DVBS:SFBHconfig:DT{channelNull_cmd_val}:DLENgth?')
		return Conversions.str_to_int(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SettingCls:
	"""Setting commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("setting", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.iq.output.analog.setting.get_catalog() \n
		Queries the files with I/Q output settings in the default directory. Listed are files with the file extension *.iqout.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:SETTing:DELete \n
		Snippet: driver.source.iq.output.analog.setting.delete(filename = 'abc') \n
		Deletes the selected file from the default or specified directory. Deleted are files with the file extension *.iqout.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: 'filename' Filename or complete file path
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:SETTing:DELete {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:SETTing:LOAD \n
		Snippet: driver.source.iq.output.analog.setting.load(filename = 'abc') \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.iqout. Refer to
		'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in a
		specific directory. \n
			:param filename: 'filename' Filename or complete file path
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:SETTing:LOAD {param}')

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:SETTing:STORe \n
		Snippet: driver.source.iq.output.analog.setting.set_store(filename = 'abc') \n
		Stores the current settings into the selected file; the file extension (*.iqout) is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: 'filename' Filename or complete file path
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:SETTing:STORe {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DumResCls:
	"""DumRes commands group definition. 15 total commands, 12 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dumRes", core, parent)

	@property
	def apMap(self):
		"""apMap commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_apMap'):
			from .ApMap import ApMapCls
			self._apMap = ApMapCls(self._core, self._cmd_group)
		return self._apMap

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def dlist(self):
		"""dlist commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dlist'):
			from .Dlist import DlistCls
			self._dlist = DlistCls(self._core, self._cmd_group)
		return self._dlist

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def naps(self):
		"""naps commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_naps'):
			from .Naps import NapsCls
			self._naps = NapsCls(self._core, self._cmd_group)
		return self._naps

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def prec(self):
		"""prec commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_prec'):
			from .Prec import PrecCls
			self._prec = PrecCls(self._core, self._cmd_group)
		return self._prec

	@property
	def scSpacing(self):
		"""scSpacing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scSpacing'):
			from .ScSpacing import ScSpacingCls
			self._scSpacing = ScSpacingCls(self._core, self._cmd_group)
		return self._scSpacing

	@property
	def sltFmt(self):
		"""sltFmt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sltFmt'):
			from .SltFmt import SltFmtCls
			self._sltFmt = SltFmtCls(self._core, self._cmd_group)
		return self._sltFmt

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def tpState(self):
		"""tpState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpState'):
			from .TpState import TpStateCls
			self._tpState = TpStateCls(self._core, self._cmd_group)
		return self._tpState

	def clone(self) -> 'DumResCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DumResCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExchangeCls:
	"""Exchange commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("exchange", core, parent)

	def get_xml_string(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SETTing:EXCHange:XMLString \n
		Snippet: value: str = driver.source.bb.nr5G.setting.exchange.get_xml_string() \n
		No command help available \n
			:return: set_exch_xml_str: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:SETTing:EXCHange:XMLString?')
		return trim_str_response(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.RepeatedCapability import RepeatedCapability
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AreaCls:
	"""Area commands group definition. 6 total commands, 5 Subgroups, 1 group commands
	Repeated Capability: ObscuredArea, default value after init: ObscuredArea.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("area", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_obscuredArea_get', 'repcap_obscuredArea_set', repcap.ObscuredArea.Nr1)

	def repcap_obscuredArea_set(self, obscuredArea: repcap.ObscuredArea) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to ObscuredArea.Default
		Default value after init: ObscuredArea.Nr1"""
		self._cmd_group.set_repcap_enum_value(obscuredArea)

	def repcap_obscuredArea_get(self) -> repcap.ObscuredArea:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def append(self):
		"""append commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_append'):
			from .Append import AppendCls
			self._append = AppendCls(self._core, self._cmd_group)
		return self._append

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def insert(self):
		"""insert commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_insert'):
			from .Insert import InsertCls
			self._insert = InsertCls(self._core, self._cmd_group)
		return self._insert

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def reference(self):
		"""reference commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reference'):
			from .Reference import ReferenceCls
			self._reference = ReferenceCls(self._core, self._cmd_group)
		return self._reference

	def delete(self, vehicle=repcap.Vehicle.Default, obscuredArea=repcap.ObscuredArea.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:AREA<CH>:DELete \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.full.area.delete(vehicle = repcap.Vehicle.Default, obscuredArea = repcap.ObscuredArea.Default) \n
		Appends, insertes or deletes an obscured zone. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:param obscuredArea: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Area')
		"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		obscuredArea_cmd_val = self._cmd_group.get_repcap_cmd_value(obscuredArea, repcap.ObscuredArea)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:AREA{obscuredArea_cmd_val}:DELete')

	def delete_with_opc(self, vehicle=repcap.Vehicle.Default, obscuredArea=repcap.ObscuredArea.Default, opc_timeout_ms: int = -1) -> None:
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		obscuredArea_cmd_val = self._cmd_group.get_repcap_cmd_value(obscuredArea, repcap.ObscuredArea)
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:AREA<CH>:DELete \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.full.area.delete_with_opc(vehicle = repcap.Vehicle.Default, obscuredArea = repcap.ObscuredArea.Default) \n
		Appends, insertes or deletes an obscured zone. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:param obscuredArea: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Area')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:AREA{obscuredArea_cmd_val}:DELete', opc_timeout_ms)

	def clone(self) -> 'AreaCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AreaCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class M2TCls:
	"""M2T commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("m2T", core, parent)

	@property
	def foffset(self):
		"""foffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_foffset'):
			from .Foffset import FoffsetCls
			self._foffset = FoffsetCls(self._core, self._cmd_group)
		return self._foffset

	@property
	def mbytes(self):
		"""mbytes commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mbytes'):
			from .Mbytes import MbytesCls
			self._mbytes = MbytesCls(self._core, self._cmd_group)
		return self._mbytes

	@property
	def rframe(self):
		"""rframe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rframe'):
			from .Rframe import RframeCls
			self._rframe = RframeCls(self._core, self._cmd_group)
		return self._rframe

	@property
	def slot(self):
		"""slot commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_slot'):
			from .Slot import SlotCls
			self._slot = SlotCls(self._core, self._cmd_group)
		return self._slot

	def clone(self) -> 'M2TCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = M2TCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, pucc_state: bool, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:SUBF<ST0>:ALLoc<CH0>:XPUCch:STATe \n
		Snippet: driver.source.bb.v5G.uplink.subf.alloc.xpucch.state.set(pucc_state = False, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the allocation state to active or inactive for the corresponding, including xPUSCH/xPUCCH and the corresponding
		reference signals. Note: Disabling an allocation does not affect other allocations of the UE. \n
			:param pucc_state: 1| ON| 0| OFF
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
		"""
		param = Conversions.bool_to_str(pucc_state)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:XPUCch:STATe {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:SUBF<ST0>:ALLoc<CH0>:XPUCch:STATe \n
		Snippet: value: bool = driver.source.bb.v5G.uplink.subf.alloc.xpucch.state.get(subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the allocation state to active or inactive for the corresponding, including xPUSCH/xPUCCH and the corresponding
		reference signals. Note: Disabling an allocation does not affect other allocations of the UE. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: pucc_state: No help available"""
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:UL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:XPUCch:STATe?')
		return Conversions.str_to_bool(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SrCls:
	"""Sr commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sr", core, parent)

	def set(self, nb_scheduling_req: bool, userEquipment=repcap.UserEquipment.Default, transmission=repcap.Transmission.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:NIOT:TRANs<CH>:HARQ:SR \n
		Snippet: driver.source.bb.eutra.uplink.ue.niot.trans.harq.sr.set(nb_scheduling_req = False, userEquipment = repcap.UserEquipment.Default, transmission = repcap.Transmission.Default) \n
		If enabled, the SR symbols are block-wise multiplied with the CSR sequence. \n
			:param nb_scheduling_req: 1| ON| 0| OFF
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param transmission: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trans')
		"""
		param = Conversions.bool_to_str(nb_scheduling_req)
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		transmission_cmd_val = self._cmd_group.get_repcap_cmd_value(transmission, repcap.Transmission)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:NIOT:TRANs{transmission_cmd_val}:HARQ:SR {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default, transmission=repcap.Transmission.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:NIOT:TRANs<CH>:HARQ:SR \n
		Snippet: value: bool = driver.source.bb.eutra.uplink.ue.niot.trans.harq.sr.get(userEquipment = repcap.UserEquipment.Default, transmission = repcap.Transmission.Default) \n
		If enabled, the SR symbols are block-wise multiplied with the CSR sequence. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param transmission: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trans')
			:return: nb_scheduling_req: 1| ON| 0| OFF"""
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		transmission_cmd_val = self._cmd_group.get_repcap_cmd_value(transmission, repcap.Transmission)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:NIOT:TRANs{transmission_cmd_val}:HARQ:SR?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TxCls:
	"""Tx commands group definition. 8 total commands, 5 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tx", core, parent)

	@property
	def antenna(self):
		"""antenna commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import AntennaCls
			self._antenna = AntennaCls(self._core, self._cmd_group)
		return self._antenna

	@property
	def calc(self):
		"""calc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_calc'):
			from .Calc import CalcCls
			self._calc = CalcCls(self._core, self._cmd_group)
		return self._calc

	@property
	def columns(self):
		"""columns commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_columns'):
			from .Columns import ColumnsCls
			self._columns = ColumnsCls(self._core, self._cmd_group)
		return self._columns

	@property
	def espacing(self):
		"""espacing commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_espacing'):
			from .Espacing import EspacingCls
			self._espacing = EspacingCls(self._core, self._cmd_group)
		return self._espacing

	@property
	def rows(self):
		"""rows commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rows'):
			from .Rows import RowsCls
			self._rows = RowsCls(self._core, self._cmd_group)
		return self._rows

	# noinspection PyTypeChecker
	def get_pattern(self) -> enums.AntMod3DaNtPattern:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:ANTenna:TX:PATTern \n
		Snippet: value: enums.AntMod3DaNtPattern = driver.source.fsimulator.scm.antenna.tx.get_pattern() \n
		Sets the antenna pattern mode. \n
			:return: pattern: ISOtropic| USER| SEC3| SEC6| DIPole| DPISotripic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:ANTenna:TX:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.AntMod3DaNtPattern)

	def set_pattern(self, pattern: enums.AntMod3DaNtPattern) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:ANTenna:TX:PATTern \n
		Snippet: driver.source.fsimulator.scm.antenna.tx.set_pattern(pattern = enums.AntMod3DaNtPattern.DIPole) \n
		Sets the antenna pattern mode. \n
			:param pattern: ISOtropic| USER| SEC3| SEC6| DIPole| DPISotripic
		"""
		param = Conversions.enum_scalar_to_str(pattern, enums.AntMod3DaNtPattern)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SCM:ANTenna:TX:PATTern {param}')

	# noinspection PyTypeChecker
	def get_structure(self) -> enums.AntModStructure:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:ANTenna:TX:STRucture \n
		Snippet: value: enums.AntModStructure = driver.source.fsimulator.scm.antenna.tx.get_structure() \n
		Sets the antenna array structure. \n
			:return: antenna_struct: LIN| CROSS
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:ANTenna:TX:STRucture?')
		return Conversions.str_to_scalar_enum(response, enums.AntModStructure)

	def set_structure(self, antenna_struct: enums.AntModStructure) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:ANTenna:TX:STRucture \n
		Snippet: driver.source.fsimulator.scm.antenna.tx.set_structure(antenna_struct = enums.AntModStructure.CROSS) \n
		Sets the antenna array structure. \n
			:param antenna_struct: LIN| CROSS
		"""
		param = Conversions.enum_scalar_to_str(antenna_struct, enums.AntModStructure)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SCM:ANTenna:TX:STRucture {param}')

	def clone(self) -> 'TxCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TxCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def get_icomponent(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:OFFSet:I \n
		Snippet: value: float = driver.source.iq.output.analog.offset.get_icomponent() \n
		Sets an offset Voffset between the inverting and non-inverting input of the differential analog I/Q output signal.
		The value range is adjusted so that the maximum overall output voltage does not exceed 4V, see 'Maximum overall output
		voltage'. \n
			:return: ipart: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:OFFSet:I?')
		return Conversions.str_to_float(response)

	def set_icomponent(self, ipart: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:OFFSet:I \n
		Snippet: driver.source.iq.output.analog.offset.set_icomponent(ipart = 1.0) \n
		Sets an offset Voffset between the inverting and non-inverting input of the differential analog I/Q output signal.
		The value range is adjusted so that the maximum overall output voltage does not exceed 4V, see 'Maximum overall output
		voltage'. \n
			:param ipart: float Range: (-4+Vp/2+Vbias/2) ,V to (4-Vp/2-Vbias/2) ,V (R&S SMW-B10) / (-2+Vp) ,V to (2-Vp) ,V (R&S SMW-B9) , Unit: V
		"""
		param = Conversions.decimal_value_to_str(ipart)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:OFFSet:I {param}')

	def get_qcomponent(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:OFFSet:Q \n
		Snippet: value: float = driver.source.iq.output.analog.offset.get_qcomponent() \n
		Sets an offset Voffset between the inverting and non-inverting input of the differential analog I/Q output signal.
		The value range is adjusted so that the maximum overall output voltage does not exceed 4V, see 'Maximum overall output
		voltage'. \n
			:return: qpart: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:OFFSet:Q?')
		return Conversions.str_to_float(response)

	def set_qcomponent(self, qpart: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:OFFSet:Q \n
		Snippet: driver.source.iq.output.analog.offset.set_qcomponent(qpart = 1.0) \n
		Sets an offset Voffset between the inverting and non-inverting input of the differential analog I/Q output signal.
		The value range is adjusted so that the maximum overall output voltage does not exceed 4V, see 'Maximum overall output
		voltage'. \n
			:param qpart: float Range: (-4+Vp/2+Vbias/2) ,V to (4-Vp/2-Vbias/2) ,V (R&S SMW-B10) / (-2+Vp) ,V to (2-Vp) ,V (R&S SMW-B9) , Unit: V
		"""
		param = Conversions.decimal_value_to_str(qpart)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:OFFSet:Q {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NameCls:
	"""Name commands group definition. 12 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("name", core, parent)

	@property
	def auto(self):
		"""auto commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def get_value(self) -> str:
		"""SCPI: HCOPy:FILE:[NAME] \n
		Snippet: value: str = driver.hardCopy.file.name.get_value() \n
		Determines the file name and path to save the hard copy, provided automatic naming is disabled. Note: If you have enabled
		automatic naming, the instrument automatically generates the file name and directory, see 'Automatic naming'. \n
			:return: name: string
		"""
		response = self._core.io.query_str('HCOPy:FILE:NAME?')
		return trim_str_response(response)

	def set_value(self, name: str) -> None:
		"""SCPI: HCOPy:FILE:[NAME] \n
		Snippet: driver.hardCopy.file.name.set_value(name = 'abc') \n
		Determines the file name and path to save the hard copy, provided automatic naming is disabled. Note: If you have enabled
		automatic naming, the instrument automatically generates the file name and directory, see 'Automatic naming'. \n
			:param name: string
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'HCOPy:FILE:NAME {param}')

	def clone(self) -> 'NameCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NameCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MovingCls:
	"""Moving commands group definition. 5 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("moving", core, parent)

	@property
	def delay(self):
		"""delay commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import DelayCls
			self._delay = DelayCls(self._core, self._cmd_group)
		return self._delay

	def get_loss(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:MDELay:MOVing:LOSS \n
		Snippet: value: float = driver.source.fsimulator.mdelay.moving.get_loss() \n
		Sets the insertion loss of the moving path for moving propagation. \n
			:return: loss: float Range: 0 to 50
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:MDELay:MOVing:LOSS?')
		return Conversions.str_to_float(response)

	def set_loss(self, loss: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MDELay:MOVing:LOSS \n
		Snippet: driver.source.fsimulator.mdelay.moving.set_loss(loss = 1.0) \n
		Sets the insertion loss of the moving path for moving propagation. \n
			:param loss: float Range: 0 to 50
		"""
		param = Conversions.decimal_value_to_str(loss)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MDELay:MOVing:LOSS {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:MDELay:MOVing:STATe \n
		Snippet: value: bool = driver.source.fsimulator.mdelay.moving.get_state() \n
		This command activates the moving fading path for moving propagation. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:MDELay:MOVing:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MDELay:MOVing:STATe \n
		Snippet: driver.source.fsimulator.mdelay.moving.set_state(state = False) \n
		This command activates the moving fading path for moving propagation. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MDELay:MOVing:STATe {param}')

	def get_vperiod(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:MDELay:MOVing:VPERiod \n
		Snippet: value: float = driver.source.fsimulator.mdelay.moving.get_vperiod() \n
		This command sets the speed of the delay variation of the moving fading path for moving propagation. A complete cycle
		comprises one pass through this 'Variation Period'. \n
			:return: vperiod: float Range: 10 to 500
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:MDELay:MOVing:VPERiod?')
		return Conversions.str_to_float(response)

	def set_vperiod(self, vperiod: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MDELay:MOVing:VPERiod \n
		Snippet: driver.source.fsimulator.mdelay.moving.set_vperiod(vperiod = 1.0) \n
		This command sets the speed of the delay variation of the moving fading path for moving propagation. A complete cycle
		comprises one pass through this 'Variation Period'. \n
			:param vperiod: float Range: 10 to 500
		"""
		param = Conversions.decimal_value_to_str(vperiod)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MDELay:MOVing:VPERiod {param}')

	def clone(self) -> 'MovingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MovingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DciCls:
	"""Dci commands group definition. 36 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dci", core, parent)

	@property
	def alloc(self):
		"""alloc commands group. 28 Sub-classes, 0 commands."""
		if not hasattr(self, '_alloc'):
			from .Alloc import AllocCls
			self._alloc = AllocCls(self._core, self._cmd_group)
		return self._alloc

	def get_awa_round(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:DCI:AWARound \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.niot.dci.get_awa_round() \n
		If enabled, the NPDSCH allocations are relocated at the beginning of the ARB sequence to ensure a consistent signal. \n
			:return: alloc_wrap_around: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:DCI:AWARound?')
		return Conversions.str_to_bool(response)

	def set_awa_round(self, alloc_wrap_around: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:DCI:AWARound \n
		Snippet: driver.source.bb.eutra.downlink.niot.dci.set_awa_round(alloc_wrap_around = False) \n
		If enabled, the NPDSCH allocations are relocated at the beginning of the ARB sequence to ensure a consistent signal. \n
			:param alloc_wrap_around: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(alloc_wrap_around)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:DCI:AWARound {param}')

	def get_nalloc(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:DCI:NALLoc \n
		Snippet: value: int = driver.source.bb.eutra.downlink.niot.dci.get_nalloc() \n
		Sets the number of configurable DCIs. \n
			:return: no_alloc: integer Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:DCI:NALLoc?')
		return Conversions.str_to_int(response)

	def set_nalloc(self, no_alloc: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:DCI:NALLoc \n
		Snippet: driver.source.bb.eutra.downlink.niot.dci.set_nalloc(no_alloc = 1) \n
		Sets the number of configurable DCIs. \n
			:param no_alloc: integer Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(no_alloc)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:DCI:NALLoc {param}')

	def clone(self) -> 'DciCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DciCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FpGenericCls:
	"""FpGeneric commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fpGeneric", core, parent)

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def dlength(self):
		"""dlength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dlength'):
			from .Dlength import DlengthCls
			self._dlength = DlengthCls(self._core, self._cmd_group)
		return self._dlength

	@property
	def plength(self):
		"""plength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_plength'):
			from .Plength import PlengthCls
			self._plength = PlengthCls(self._core, self._cmd_group)
		return self._plength

	def clone(self) -> 'FpGenericCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FpGenericCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPyCls:
	"""FilterPy commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("filterPy", core, parent)

	def get_bfactor(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:FILTer:BFACtor \n
		Snippet: value: float = driver.source.bb.nr5G.output.filterPy.get_bfactor() \n
		No command help available \n
			:return: bw_factor: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:OUTPut:FILTer:BFACtor?')
		return Conversions.str_to_float(response)

	def set_bfactor(self, bw_factor: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:FILTer:BFACtor \n
		Snippet: driver.source.bb.nr5G.output.filterPy.set_bfactor(bw_factor = 1.0) \n
		No command help available \n
			:param bw_factor: No help available
		"""
		param = Conversions.decimal_value_to_str(bw_factor)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:OUTPut:FILTer:BFACtor {param}')

	def get_bw_2_factor(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:FILTer:BW2Factor \n
		Snippet: value: float = driver.source.bb.nr5G.output.filterPy.get_bw_2_factor() \n
		No command help available \n
			:return: band_2_factor: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:OUTPut:FILTer:BW2Factor?')
		return Conversions.str_to_float(response)

	def set_bw_2_factor(self, band_2_factor: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:FILTer:BW2Factor \n
		Snippet: driver.source.bb.nr5G.output.filterPy.set_bw_2_factor(band_2_factor = 1.0) \n
		No command help available \n
			:param band_2_factor: No help available
		"""
		param = Conversions.decimal_value_to_str(band_2_factor)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:OUTPut:FILTer:BW2Factor {param}')

	def get_custom(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:FILTer:CUSTom \n
		Snippet: value: bool = driver.source.bb.nr5G.output.filterPy.get_custom() \n
		No command help available \n
			:return: use_custom: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:OUTPut:FILTer:CUSTom?')
		return Conversions.str_to_bool(response)

	def set_custom(self, use_custom: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:FILTer:CUSTom \n
		Snippet: driver.source.bb.nr5G.output.filterPy.set_custom(use_custom = False) \n
		No command help available \n
			:param use_custom: No help available
		"""
		param = Conversions.bool_to_str(use_custom)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:OUTPut:FILTer:CUSTom {param}')

	def get_tabs(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:FILTer:TABS \n
		Snippet: value: int = driver.source.bb.nr5G.output.filterPy.get_tabs() \n
		No command help available \n
			:return: filter_tabs: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:OUTPut:FILTer:TABS?')
		return Conversions.str_to_int(response)

	def set_tabs(self, filter_tabs: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:FILTer:TABS \n
		Snippet: driver.source.bb.nr5G.output.filterPy.set_tabs(filter_tabs = 1) \n
		No command help available \n
			:param filter_tabs: No help available
		"""
		param = Conversions.decimal_value_to_str(filter_tabs)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:OUTPut:FILTer:TABS {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 6 total commands, 5 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def dcycle(self):
		"""dcycle commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dcycle'):
			from .Dcycle import DcycleCls
			self._dcycle = DcycleCls(self._core, self._cmd_group)
		return self._dcycle

	@property
	def dselection(self):
		"""dselection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dselection'):
			from .Dselection import DselectionCls
			self._dselection = DselectionCls(self._core, self._cmd_group)
		return self._dselection

	@property
	def fdelay(self):
		"""fdelay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fdelay'):
			from .Fdelay import FdelayCls
			self._fdelay = FdelayCls(self._core, self._cmd_group)
		return self._fdelay

	@property
	def fduration(self):
		"""fduration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fduration'):
			from .Fduration import FdurationCls
			self._fduration = FdurationCls(self._core, self._cmd_group)
		return self._fduration

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	def set(self, data: enums.WlannDataSource, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:DATA \n
		Snippet: driver.source.bb.wlnn.fblock.data.set(data = enums.WlannDataSource.AMPDU, frameBlock = repcap.FrameBlock.Default) \n
		Selects the data source. \n
			:param data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| AMPDU PNxx The pseudo-random sequence generator is used as the data source. Different random sequence lengths can be selected. DLISt A data list is used. The data list is selected with the command BB:WLNN:FBLocks:DATA:DSEL ZERO | ONE Internal 0 and 1 data is used. PATTern Internal data is used. The bit pattern for the data is defined by the command BB:WLNN:FBLocks:DATA:PATTern. AMPDU Aggregated mac protocol data unit (A-MPDU) data is used as configured with the commands in 'MPDU configuration'
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.enum_scalar_to_str(data, enums.WlannDataSource)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, frameBlock=repcap.FrameBlock.Default) -> enums.WlannDataSource:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:DATA \n
		Snippet: value: enums.WlannDataSource = driver.source.bb.wlnn.fblock.data.get(frameBlock = repcap.FrameBlock.Default) \n
		Selects the data source. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| AMPDU PNxx The pseudo-random sequence generator is used as the data source. Different random sequence lengths can be selected. DLISt A data list is used. The data list is selected with the command BB:WLNN:FBLocks:DATA:DSEL ZERO | ONE Internal 0 and 1 data is used. PATTern Internal data is used. The bit pattern for the data is defined by the command BB:WLNN:FBLocks:DATA:PATTern. AMPDU Aggregated mac protocol data unit (A-MPDU) data is used as configured with the commands in 'MPDU configuration'"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.WlannDataSource)

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TcInterfererCls:
	"""TcInterferer commands group definition. 21 total commands, 2 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tcInterferer", core, parent)

	@property
	def moving(self):
		"""moving commands group. 2 Sub-classes, 5 commands."""
		if not hasattr(self, '_moving'):
			from .Moving import MovingCls
			self._moving = MovingCls(self._core, self._cmd_group)
		return self._moving

	@property
	def reference(self):
		"""reference commands group. 2 Sub-classes, 5 commands."""
		if not hasattr(self, '_reference'):
			from .Reference import ReferenceCls
			self._reference = ReferenceCls(self._core, self._cmd_group)
		return self._reference

	def get_period(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:PERiod \n
		Snippet: value: float = driver.source.fsimulator.tcInterferer.get_period() \n
		Sets either the dwell time or the period for a complete cycle of the moving path. \n
			:return: period: float Range: 0.1 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:TCINterferer:PERiod?')
		return Conversions.str_to_float(response)

	def set_period(self, period: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:PERiod \n
		Snippet: driver.source.fsimulator.tcInterferer.set_period(period = 1.0) \n
		Sets either the dwell time or the period for a complete cycle of the moving path. \n
			:param period: float Range: 0.1 to 10
		"""
		param = Conversions.decimal_value_to_str(period)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:TCINterferer:PERiod {param}')

	def get_speed(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:SPEed \n
		Snippet: value: float = driver.source.fsimulator.tcInterferer.get_speed() \n
		Sets the speed v of the moving receiver for 2 channel interferer fading. \n
			:return: speed: float Range: 0 to 27778 (dynamic)
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:TCINterferer:SPEed?')
		return Conversions.str_to_float(response)

	def set_speed(self, speed: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:SPEed \n
		Snippet: driver.source.fsimulator.tcInterferer.set_speed(speed = 1.0) \n
		Sets the speed v of the moving receiver for 2 channel interferer fading. \n
			:param speed: float Range: 0 to 27778 (dynamic)
		"""
		param = Conversions.decimal_value_to_str(speed)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:TCINterferer:SPEed {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:[STATe] \n
		Snippet: value: bool = driver.source.fsimulator.tcInterferer.get_state() \n
		Activates the 2 channel interferer fading configuration. The paths and the fading simulator must be switched on
		separately, see [:SOURce<hw>]:FSIMulator:TCINterferer:REFerence|MOVing:STATe and [:SOURce<hw>]:FSIMulator[:STATe]. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:TCINterferer:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:[STATe] \n
		Snippet: driver.source.fsimulator.tcInterferer.set_state(state = False) \n
		Activates the 2 channel interferer fading configuration. The paths and the fading simulator must be switched on
		separately, see [:SOURce<hw>]:FSIMulator:TCINterferer:REFerence|MOVing:STATe and [:SOURce<hw>]:FSIMulator[:STATe]. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:TCINterferer:STATe {param}')

	def clone(self) -> 'TcInterfererCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TcInterfererCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def get(self, satelliteSvid=repcap.SatelliteSvid.Default, vehicle=repcap.Vehicle.Default, antenna=repcap.Antenna.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GPS:MPATh:[V<US>]:[A<GR>]:LOS:POWer \n
		Snippet: value: float = driver.source.bb.gnss.svid.gps.mpath.v.a.los.power.get(satelliteSvid = repcap.SatelliteSvid.Default, vehicle = repcap.Vehicle.Default, antenna = repcap.Antenna.Default) \n
		Sets the additional power offset for the selected echoes. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:param antenna: optional repeated capability selector. Default value: Nr1 (settable in the interface 'A')
			:return: power_offset: float Range: -15 to 0, Unit: dB"""
		satelliteSvid_cmd_val = self._cmd_group.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		antenna_cmd_val = self._cmd_group.get_repcap_cmd_value(antenna, repcap.Antenna)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GPS:MPATh:V{vehicle_cmd_val}:A{antenna_cmd_val}:LOS:POWer?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	def set(self, power: float, path=repcap.Path.Default) -> None:
		"""SCPI: SCONfiguration:EXTernal:RF<CH>:RF:POWer \n
		Snippet: driver.sconfiguration.external.rf.rf.power.set(power = 1.0, path = repcap.Path.Default) \n
		In uncoupled mode, sets the RF level of the external instrument. \n
			:param power: float Range: -130 to 20
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
		"""
		param = Conversions.decimal_value_to_str(power)
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SCONfiguration:EXTernal:RF{path_cmd_val}:RF:POWer {param}')

	def get(self, path=repcap.Path.Default) -> float:
		"""SCPI: SCONfiguration:EXTernal:RF<CH>:RF:POWer \n
		Snippet: value: float = driver.sconfiguration.external.rf.rf.power.get(path = repcap.Path.Default) \n
		In uncoupled mode, sets the RF level of the external instrument. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:return: power: float Range: -130 to 20"""
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SCONfiguration:EXTernal:RF{path_cmd_val}:RF:POWer?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
